@@ -16,6 +16,7 @@ extensions = [
     'sphinx.ext.intersphinx',
     'sphinx.ext.viewcode',
     'sphinx.ext.napoleon',  # support for NumPy-style docstrings
+    'sphinx_last_updated_by_git',
 ]
 
 autoclass_content = 'init'
@@ -41,7 +42,6 @@ master_doc = 'index'
 
 authors = 'Matthias Geier'
 project = 'python-sounddevice'
-copyright = '2020, ' + authors
 
 try:
     release = check_output(['git', 'describe', '--tags', '--always'])
@@ -55,18 +55,19 @@ try:
 except Exception:
     today = '<unknown date>'
 
-default_role = 'any'
+default_role = 'py:obj'
 
 nitpicky = True
 
-html_theme = 'sphinx_rtd_theme'
+html_theme = 'insipid'
 html_theme_options = {
-    'collapse_navigation': False,
 }
 html_title = project + ', version ' + release
+html_favicon = 'favicon.svg'
 html_domain_indices = False
-html_show_sourcelink = True
 html_show_copyright = False
+html_copy_source = False
+html_permalinks_icon = '§'
 htmlhelp_basename = 'python-sounddevice'
 
 latex_elements = {
