@@ -254,7 +254,8 @@ typedef enum PaWasapiFlags
     paWinWasapiRedirectHostProcessor    = 2,
     paWinWasapiUseChannelMask           = 4,
     paWinWasapiPolling                  = 8,
-    paWinWasapiThreadPriority           = 16
+    paWinWasapiThreadPriority           = 16,
+    paWinWasapiAutoConvert              = 64
 } PaWasapiFlags;
 
 typedef void (*PaWasapiHostProcessorCallback) (
@@ -307,14 +308,10 @@ typedef struct PaWasapiStreamInfo
     PaWasapiStreamCategory streamCategory;
     PaWasapiStreamOption streamOption;
 } PaWasapiStreamInfo;
-""")
 
-ffibuilder.cdef("""
-    /* from stdio.h */
-    FILE* fopen(const char* path, const char* mode);
-    int fclose(FILE* fp);
-    FILE* stderr;  /* GNU C library */
-    FILE* __stderrp;  /* macOS */
+PaError PaWasapi_UpdateDeviceList();
+
+int PaWasapi_IsLoopback( PaDeviceIndex device );
 """)
 
 if __name__ == '__main__':
